@@ -158,10 +158,8 @@ nautilus_hardware_view_init (NautilusHardwareView *hardware_view)
 
 	hardware_view->details->nautilus_view = nautilus_view_new (GTK_WIDGET (hardware_view));
 
-	g_signal_connect (hardware_view->details->nautilus_view, 
-			  "load_location",
-			  G_CALLBACK (hardware_view_load_location_callback), 
-			  hardware_view);
+	g_signal_connect_object (hardware_view->details->nautilus_view, "load_location",
+                                 G_CALLBACK (hardware_view_load_location_callback), hardware_view, 0);
 
   	background = eel_get_widget_background (GTK_WIDGET (hardware_view));
   	eel_background_set_color (background, HARDWARE_DEFAULT_BACKGROUND_COLOR);
@@ -193,12 +191,8 @@ nautilus_hardware_view_destroy (GtkObject *object)
 
         hardware_view = NAUTILUS_HARDWARE_VIEW (object);
 
-	/* free the property bag */
-	if (hardware_view->details->property_bag != NULL) {
-		bonobo_object_unref (BONOBO_OBJECT (hardware_view->details->property_bag));
-	}
+        bonobo_object_unref (hardware_view->details->property_bag);
 	
-	/* remove the timer task */
 	if (hardware_view->details->timer_task != 0) {
 		gtk_timeout_remove (hardware_view->details->timer_task);
 	}
@@ -209,10 +203,10 @@ nautilus_hardware_view_destroy (GtkObject *object)
 }
 
 /* Component embedding support */
-NautilusView *
+BonoboObject *
 nautilus_hardware_view_get_nautilus_view (NautilusHardwareView *hardware_view)
 {
-	return hardware_view->details->nautilus_view;
+	return BONOBO_OBJECT (hardware_view->details->nautilus_view);
 }
 
 static char * 
@@ -442,7 +436,9 @@ setup_form_title (NautilusHardwareView *view,
 	gtk_widget_show(temp_container);
 	
 	if (image_name != NULL) {
- 		file_name = gnome_pixmap_file (image_name);
+ 		file_name = gnome_program_locate_file (
+                        NULL, GNOME_FILE_DOMAIN_PIXMAP, image_name, TRUE, NULL);
+		
 		if (file_name != NULL) {
 			temp_widget = gtk_image_new_from_file (file_name);
 			gtk_box_pack_start (GTK_BOX(temp_container), temp_widget, 0, 0, 8);		
@@ -452,7 +448,7 @@ setup_form_title (NautilusHardwareView *view,
 	}
 	
  	temp_widget = gtk_label_new (title_text);
-	eel_gtk_label_set_scale (GTK_LABEL (temp_widget), PANGO_SCALE_X_LARGE);
+	eel_gtk_label_set_scale (GTK_LABEL (temp_widget), PANGO_SCALE_XX_LARGE);
 
 	gtk_box_pack_start (GTK_BOX (temp_container), temp_widget, 0, 0, 8);			 	
 	gtk_widget_show (temp_widget);
@@ -535,6 +531,7 @@ setup_overview_form (NautilusHardwareView *view)
 		
 		temp_widget = gtk_label_new (temp_text);
 		eel_gtk_label_set_scale (GTK_LABEL (temp_widget), PANGO_SCALE_LARGE);
+		gtk_label_set_justify (GTK_LABEL (temp_widget), GTK_JUSTIFY_CENTER);
 		g_free(temp_text);
 		gtk_box_pack_start(GTK_BOX(temp_box), temp_widget, 0, 0, 0 );			
 		gtk_widget_show (temp_widget);
@@ -578,12 +575,12 @@ setup_overview_form (NautilusHardwareView *view)
                                 
                                 /* Set the icon depending on the type of device */
                                 if (strcmp (ide_media, "disk\n") == 0) {
-                                        file_name = nautilus_pixmap_file ("i-harddisk.png");
+                                        file_name = nautilus_pixmap_file ("HD_drive.png");
                                 } else if (strcmp (ide_media, "cdrom\n") == 0) {
                                         file_name = nautilus_pixmap_file ("CD_drive.png");
                                 } else {
                                         /* some other device ... still set an icon */
-                                        file_name = nautilus_pixmap_file ("i-harddisk.png");
+                                        file_name = nautilus_pixmap_file ("HD_drive.png");
                                 }
                                 
 				pixmap_widget = gtk_image_new_from_file (file_name);
@@ -638,7 +635,7 @@ setup_CPU_form (NautilusHardwareView *view)
 	message = _("This is a placeholder for the CPU page.");
 	temp_widget = gtk_label_new (message);
 	eel_gtk_label_set_scale (GTK_LABEL (temp_widget), PANGO_SCALE_LARGE);
- 	gtk_label_set_wrap (GTK_LABEL (temp_widget), TRUE);
+ 	gtk_label_set_line_wrap (GTK_LABEL (temp_widget), TRUE);
 	
 	gtk_box_pack_start(GTK_BOX(view->details->form), temp_widget, 0, 0, 12);			
  	gtk_widget_show (temp_widget);
@@ -663,7 +660,7 @@ setup_RAM_form (NautilusHardwareView *view)
 	message = _("This is a placeholder for the RAM page.");
 	temp_widget = gtk_label_new (message);
 	eel_gtk_label_set_scale (GTK_LABEL (temp_widget), PANGO_SCALE_LARGE);
- 	gtk_label_set_wrap (GTK_LABEL (temp_widget), TRUE);
+ 	gtk_label_set_line_wrap (GTK_LABEL (temp_widget), TRUE);
 	
 	gtk_box_pack_start(GTK_BOX(view->details->form), temp_widget, 0, 0, 12);			
  	gtk_widget_show (temp_widget);
@@ -688,7 +685,7 @@ setup_IDE_form (NautilusHardwareView *view)
         message = _("This is a placeholder for the IDE page.");
         temp_widget = gtk_label_new (message);
 	eel_gtk_label_set_scale (GTK_LABEL (temp_widget), PANGO_SCALE_LARGE);
-        gtk_label_set_wrap (GTK_LABEL (temp_widget), TRUE);
+        gtk_label_set_line_wrap (GTK_LABEL (temp_widget), TRUE);
         
         gtk_box_pack_start(GTK_BOX(view->details->form), temp_widget, 0, 0, 12);            
         gtk_widget_show (temp_widget);
