@@ -161,14 +161,14 @@ nautilus_text_view_init (NautilusTextView *text_view)
 	text_view->details->zoomable = bonobo_zoomable_new ();
 	text_view->details->zoom_index = 3;
 	
-	g_signal_connect (text_view->details->zoomable, "set_zoom_level",
-			    G_CALLBACK (zoomable_set_zoom_level_callback), text_view);
-	g_signal_connect (text_view->details->zoomable, "zoom_in",
-			    G_CALLBACK (zoomable_zoom_in_callback), text_view);
-	g_signal_connect (text_view->details->zoomable, "zoom_out",
-			    G_CALLBACK (zoomable_zoom_out_callback), text_view);
-	g_signal_connect (text_view->details->zoomable, "zoom_to_fit",
-			    G_CALLBACK (zoomable_zoom_to_fit_callback), text_view);
+	g_signal_connect_object (text_view->details->zoomable, "set_zoom_level",
+                                 G_CALLBACK (zoomable_set_zoom_level_callback), text_view, 0);
+	g_signal_connect_object (text_view->details->zoomable, "zoom_in",
+                                 G_CALLBACK (zoomable_zoom_in_callback), text_view, 0);
+	g_signal_connect_object (text_view->details->zoomable, "zoom_out",
+                                 G_CALLBACK (zoomable_zoom_out_callback), text_view, 0);
+	g_signal_connect_object (text_view->details->zoomable, "zoom_to_fit",
+                                 G_CALLBACK (zoomable_zoom_to_fit_callback), text_view, 0);
 	
 	bonobo_zoomable_set_parameters_full (text_view->details->zoomable,
 					     1.0, .25, 4.0, TRUE, TRUE, FALSE,
@@ -179,10 +179,8 @@ nautilus_text_view_init (NautilusTextView *text_view)
 				     BONOBO_OBJECT (text_view->details->zoomable));
  
     	
-	g_signal_connect (text_view, 
-			    "load_location",
-			    G_CALLBACK (text_view_load_location_callback), 
-			    text_view);
+	g_signal_connect_object (text_view, "load_location",
+                                 G_CALLBACK (text_view_load_location_callback), text_view, 0);
 			    	
 	/* allocate a vbox to contain the text widget */
 	text_view->details->container = gtk_vbox_new (FALSE, 0);
@@ -225,11 +223,10 @@ nautilus_text_view_init (NautilusTextView *text_view)
 	gtk_container_add (GTK_CONTAINER (text_view->details->container), scrolled_window);
 
 	/* get notified when we are activated so we can merge in our menu items */
-        g_signal_connect (nautilus_view_get_bonobo_control (NAUTILUS_VIEW (text_view)),
-                          "activate",
-                          G_CALLBACK (merge_bonobo_menu_items),
-                          text_view);
-		 	
+        g_signal_connect_object (nautilus_view_get_bonobo_control (NAUTILUS_VIEW (text_view)),
+                                 "activate",
+                                 G_CALLBACK (merge_bonobo_menu_items), text_view, 0);
+        
 	/* finally, we can show everything */	
 	gtk_widget_show_all (GTK_WIDGET (text_view->details->event_box));
 }
@@ -443,7 +440,7 @@ nautilus_text_view_update_font (NautilusTextView *text_view)
 	GdkFont *font;
 	int font_size;
 
-	font_size = eel_preferences_get_integer (NAUTILUS_PREFERENCES_TEXT_VIEW_STANDARD_FONT_SIZE);
+	font_size = eel_preferences_get_enum (NAUTILUS_PREFERENCES_TEXT_VIEW_STANDARD_FONT_SIZE);
 
 	font_size += text_view_font_size_deltas[text_view->details->zoom_index];
 
@@ -795,8 +792,8 @@ merge_bonobo_menu_items (BonoboControl *control, gboolean state, gpointer user_d
 
 		nautilus_text_view_build_service_menu (text_view, control);
 
-                g_signal_connect (bonobo_control_get_ui_component (control),
-                                    "ui_event", G_CALLBACK (handle_ui_event), text_view);
+                g_signal_connect_object (bonobo_control_get_ui_component (control), "ui_event",
+                                         G_CALLBACK (handle_ui_event), text_view, 0);
                 
 		nautilus_clipboard_set_up_editable_in_control (GTK_EDITABLE (text_view->details->text_display),
 						       		control,
