@@ -67,15 +67,16 @@
 #define MAX_AUTOSCROLL_DELTA 50
 
 void
-nautilus_drag_init (NautilusDragInfo *drag_info,
-	       const GtkTargetEntry *drag_types, int drag_type_count, 
-	       GdkBitmap *stipple)
+nautilus_drag_init (NautilusDragInfo     *drag_info,
+		    const GtkTargetEntry *drag_types,
+		    int                   drag_type_count, 
+		    GdkBitmap            *stipple)
 {
 	drag_info->target_list = gtk_target_list_new (drag_types,
 						   drag_type_count);
 
 	if (stipple != NULL) {
-		drag_info->stipple = gdk_bitmap_ref (stipple);
+		drag_info->stipple = g_object_ref (stipple);
 	}
 
 	drag_info->drop_occured = FALSE;
@@ -89,7 +90,7 @@ nautilus_drag_finalize (NautilusDragInfo *drag_info)
 	nautilus_drag_destroy_selection_list (drag_info->selection_list);
 
 	if (drag_info->stipple != NULL) {
-		gdk_bitmap_unref (drag_info->stipple);
+		g_object_unref (drag_info->stipple);
 	}
 
 	g_free (drag_info);
