@@ -58,25 +58,24 @@ struct NautilusDragWindowDetails {
  */
 #define NAUTILUS_DRAG_WINDOW_DETAILS_KEY "nautilus-drag-window-details"
 
-static Atom sawfish_wm_raise_window = 0;
-
 /* Return the nearest ancestor of WIDGET that has type WIDGET_TYPE. But only
  * if there's no widget between the two with type BLOCKING_TYPE.
  */
 static GtkWidget *
 get_ancestor_blocked_by (GtkWidget *widget,
-			 GtkType widget_type,
-			 GtkType blocking_type)
+			 GType      widget_type,
+			 GType      blocking_type)
 {
-	g_return_val_if_fail (widget != NULL, NULL);
 	g_return_val_if_fail (GTK_IS_WIDGET (widget), NULL);
 
 	while (widget != NULL)
 	{
-		if (gtk_type_is_a (GTK_WIDGET_TYPE (widget), widget_type))
+		if (g_type_is_a (GTK_WIDGET_TYPE (widget), widget_type))
 			return widget;
-		else if (gtk_type_is_a (GTK_WIDGET_TYPE (widget), blocking_type))
+
+		else if (g_type_is_a (GTK_WIDGET_TYPE (widget), blocking_type))
 			return NULL;
+
 		widget = widget->parent;
 	}
 
@@ -114,8 +113,6 @@ execute_pending_requests (GtkWindow *window,
 	}
 }
 
-#if GNOME2_CONVERSION_COMPLETE
-
 /* Called when no button-press event arrived occurred shortly after
  * receiving a TAKE_FOCUS or RAISE_WINDOW request. So just commit
  * the pending requests.
@@ -139,7 +136,6 @@ focus_timeout_callback (gpointer data)
 	return FALSE;
 }
 
-#endif
 
 static void
 remove_focus_timeout (GtkWindow *window)
@@ -154,8 +150,6 @@ remove_focus_timeout (GtkWindow *window)
 	}
 }
 
-#if GNOME2_CONVERSION_COMPLETE
-
 static void
 set_focus_timeout (GtkWindow *window)
 {
@@ -171,8 +165,6 @@ set_focus_timeout (GtkWindow *window)
 	}
 }
 
-#endif
-
 /* Called for all button-press events; sets the `in_button_press' flag */
 static gboolean
 button_press_emission_callback (GSignalInvocationHint *ihint,
@@ -245,11 +237,12 @@ drag_begin_emission_callback (GSignalInvocationHint *ihint,
 	GtkWidget *window;
 	NautilusDragWindowDetails *details;
 
-	window = gtk_widget_get_ancestor (GTK_WIDGET (g_value_get_object (&params[0])),
-					  GTK_TYPE_WINDOW);
+        window = gtk_widget_get_toplevel (GTK_WIDGET (g_value_get_object (&params[0])));
+
 	if (window != NULL) {
 		details = get_details (GTK_WINDOW (window));
 		if (details != NULL) {
+
 			details->pending_focus = FALSE;
 			details->pending_raise = FALSE;
 		}
@@ -258,8 +251,6 @@ drag_begin_emission_callback (GSignalInvocationHint *ihint,
 	return TRUE;
 }
 
-#if GNOME2_CONVERSION_COMPLETE
-
 /* The process-wide filter for WM_PROTOCOLS client messages */
 static GdkFilterReturn
 wm_protocols_filter (GdkXEvent *xev, GdkEvent *event, gpointer data)
@@ -277,7 +268,7 @@ wm_protocols_filter (GdkXEvent *xev, GdkEvent *event, gpointer data)
 		details = NULL;
 	}
 
-	if ((Atom) xevent->xclient.data.l[0] == gdk_wm_delete_window) {
+	if ((Atom) xevent->xclient.data.l[0] == gdk_x11_get_xatom_by_name ("WM_DELETE_WINDOW")) {
 
 		/* (copied from gdkevents.c) */
 
@@ -293,7 +284,7 @@ wm_protocols_filter (GdkXEvent *xev, GdkEvent *event, gpointer data)
 		event->any.type = GDK_DELETE;
 		return GDK_FILTER_TRANSLATE;
 
-	} else if ((Atom) xevent->xclient.data.l[0] == gdk_wm_take_focus) {
+	} else if ((Atom) xevent->xclient.data.l[0] == gdk_x11_get_xatom_by_name ("WM_TAKE_FOCUS")) {
 
 		if (details != NULL) {
 			details->pending_focus = TRUE;
@@ -306,7 +297,7 @@ wm_protocols_filter (GdkXEvent *xev, GdkEvent *event, gpointer data)
 		}
 		return GDK_FILTER_REMOVE;
 
-	} else if ((Atom) xevent->xclient.data.l[0] == sawfish_wm_raise_window) {
+	} else if ((Atom) xevent->xclient.data.l[0] == gdk_x11_get_xatom_by_name ("_SAWFISH_WM_RAISE_WINDOW")) {
 
 		if (details != NULL) {
 			details->pending_raise = TRUE;
@@ -323,24 +314,15 @@ wm_protocols_filter (GdkXEvent *xev, GdkEvent *event, gpointer data)
 	}
 }
 
-#endif
-
 static void
 nautilus_drag_window_destroy (GtkObject *object, gpointer data)
 {
-	NautilusDragWindowDetails *details;
-
-	details = get_details (GTK_WINDOW (object));
-	
 	remove_focus_timeout (GTK_WINDOW (object));
-
-	/* The `details' will be freed automatically */
 }
 
 static void
 nautilus_drag_window_realize (GtkWidget *widget, gpointer data)
 {
-#if GNOME2_CONVERSION_COMPLETE
 	GdkAtom protocols[3];
 
 	/* Tell the window manager _not_ to focus this window by itself */
@@ -351,11 +333,10 @@ nautilus_drag_window_realize (GtkWidget *widget, gpointer data)
 	 * the window. (This won't work with other wm's, but it won't
 	 * break anything either.)
 	 */
-	protocols[0] = gdk_wm_delete_window;
-	protocols[1] = gdk_wm_take_focus;
-	protocols[2] = sawfish_wm_raise_window;
+        protocols[0] = gdk_atom_intern ("WM_DELETE_WINDOW", FALSE);
+        protocols[1] = gdk_atom_intern ("WM_TAKE_FOCUS", FALSE);
+        protocols[2] = gdk_atom_intern ("_NET_WM_PING", FALSE);
 	eel_gdk_window_set_wm_protocols (widget->window, protocols, 3);
-#endif
 }
 
 /* Public entry point */
@@ -385,19 +366,11 @@ nautilus_drag_window_register (GtkWindow *window)
 		g_signal_add_emission_hook (signal_id, 0,
                                             drag_begin_emission_callback, NULL, NULL);
 
-		/* Intern the necessary X atoms
-		 */
-		sawfish_wm_raise_window = XInternAtom (GDK_DISPLAY (),
-						       "_SAWFISH_WM_RAISE_WINDOW",
-						       False);
-
-#if GNOME2_CONVERSION_COMPLETE
 		/* Override the standard GTK filter for handling WM_PROTOCOLS
 		 * client messages
 		 */
-		gdk_add_client_message_filter (gdk_wm_protocols,
+		gdk_add_client_message_filter (gdk_atom_intern ("WM_PROTOCOLS", FALSE), 
 					       wm_protocols_filter, NULL);
-#endif
 
 		initialized = TRUE;
 	}
@@ -409,7 +382,7 @@ nautilus_drag_window_register (GtkWindow *window)
                                 details, g_free);
 
 	g_signal_connect (window, "realize",
-			    G_CALLBACK (nautilus_drag_window_realize), NULL);
+                          G_CALLBACK (nautilus_drag_window_realize), NULL);
 	g_signal_connect (window, "destroy",
-			    G_CALLBACK (nautilus_drag_window_destroy), NULL);
+                          G_CALLBACK (nautilus_drag_window_destroy), NULL);
 }
