@@ -78,7 +78,6 @@
 #define READ_CHUNK_SIZE 16384
 
 /* Paths to use when creating & referring to Bonobo menu items */
-#define MENU_PATH_RENAME 			"/menu/File/File Items Placeholder/Rename"
 #define MENU_PATH_STRETCH_ICON 			"/menu/Edit/Edit Items Placeholder/Stretch"
 #define MENU_PATH_UNSTRETCH_ICONS 		"/menu/Edit/Edit Items Placeholder/Unstretch"
 #define MENU_PATH_LAY_OUT			"/menu/View/View Items Placeholder/Lay Out"
@@ -90,7 +89,6 @@
 #define POPUP_PATH_LAY_OUT			"/popups/background/Before Zoom Items/View Items/Lay Out"
 
 #define COMMAND_PREFIX                          "/commands/"
-#define COMMAND_RENAME 				"/commands/Rename"
 #define COMMAND_STRETCH_ICON 			"/commands/Stretch"
 #define COMMAND_UNSTRETCH_ICONS 		"/commands/Unstretch"
 #define COMMAND_TIGHTER_LAYOUT 			"/commands/Tighter Layout"
@@ -183,6 +181,7 @@ static const SortCriterion sort_criteria[] = {
 
 static gboolean default_sort_in_reverse_order = FALSE;
 static int preview_sound_auto_value;
+static gboolean gnome_esd_enabled_auto_value;
 
 static void                 fm_icon_view_set_directory_sort_by                 (FMIconView           *icon_view,
 										NautilusFile         *file,
@@ -380,19 +379,6 @@ clean_up_callback (BonoboUIComponent *component, gpointer callback_data, const c
 	fm_icon_view_clean_up (FM_ICON_VIEW (callback_data));
 }
 
-	
-
-static void
-rename_icon_callback (BonoboUIComponent *component, gpointer callback_data, const char *verb)
-{
-	g_assert (FM_IS_ICON_VIEW (callback_data));
-  		
-	nautilus_icon_container_start_renaming_selected_item
-		(get_icon_container (FM_ICON_VIEW (callback_data)));
-
-	fm_directory_view_update_menus (FM_DIRECTORY_VIEW (callback_data));
-}
-
 static void
 set_tighter_layout (FMIconView *icon_view, gboolean new_value)
 {
@@ -1261,11 +1247,23 @@ layout_changed_callback (NautilusIconContainer *container,
 	update_layout_menus (icon_view);
 }
 
+static gboolean
+fm_icon_view_can_rename_file (FMDirectoryView *view, NautilusFile *file)
+{
+	if (!(fm_icon_view_get_zoom_level (FM_ICON_VIEW (view)) > NAUTILUS_ZOOM_LEVEL_SMALLEST)) {
+		return FALSE;
+	}
+
+	return EEL_CALL_PARENT_WITH_RETURN_VALUE (
+		FM_DIRECTORY_VIEW_CLASS, can_rename_file, (view, file));
+}
+
 static void
-fm_icon_view_start_renaming_item  (FMDirectoryView *view, const char *uri)
+fm_icon_view_start_renaming_file (FMDirectoryView *view, NautilusFile *file)
 {
 	/* call parent class to make sure the right icon is selected */
-	EEL_CALL_PARENT (FM_DIRECTORY_VIEW_CLASS, start_renaming_item, (view, uri));
+	EEL_CALL_PARENT (FM_DIRECTORY_VIEW_CLASS, start_renaming_file, (view, file));
+	
 	/* start renaming */
 	nautilus_icon_container_start_renaming_selected_item
 		(get_icon_container (FM_ICON_VIEW (view)));
@@ -1290,7 +1288,6 @@ fm_icon_view_merge_menus (FMDirectoryView *view)
 	FMIconView *icon_view;
 	Bonobo_UIContainer ui_container;
 	BonoboUIVerb verbs [] = {
-		BONOBO_UI_VERB ("Rename", rename_icon_callback),
 		BONOBO_UI_VERB ("Stretch", show_stretch_handles_callback),
 		BONOBO_UI_VERB ("Unstretch", unstretch_icons_callback),
 		BONOBO_UI_VERB ("Clean Up", clean_up_callback),
@@ -1383,12 +1380,6 @@ fm_icon_view_update_menus (FMDirectoryView *view)
 				       icon_container != NULL
 			    	       && nautilus_icon_container_is_stretched (icon_container));
 
-	nautilus_bonobo_set_sensitive (icon_view->details->ui, 
-				       COMMAND_RENAME,
-				       selection_count == 1
-				       && fm_icon_view_get_zoom_level (icon_view) > NAUTILUS_ZOOM_LEVEL_SMALLEST
-				       && nautilus_file_can_rename (selection->data));
-				       
 	bonobo_ui_component_thaw (icon_view->details->ui, NULL);
 	
 	nautilus_file_list_free (selection);
@@ -1666,17 +1657,10 @@ preview_audio (FMIconView *icon_view, NautilusFile *file, gboolean start_flag)
 }
 
 static gboolean
-should_preview_sound (NautilusFile *file) {
-
-	GConfClient *client;
-	gboolean enable_esd = FALSE;
-        
-	client = gconf_client_get_default ();
-	enable_esd = gconf_client_get_bool (client, "/desktop/gnome/sound/enable_esd", NULL);
-	g_object_unref (client);
-
+should_preview_sound (NautilusFile *file)
+{
 	/* Check gnome config sound preference */
-	if (!enable_esd) {
+	if (!gnome_esd_enabled_auto_value) {
 		return FALSE;
 	}
 
@@ -2639,6 +2623,7 @@ fm_icon_view_class_init (FMIconViewClass *klass)
 	fm_directory_view_class->add_file = fm_icon_view_add_file;
 	fm_directory_view_class->begin_loading = fm_icon_view_begin_loading;
 	fm_directory_view_class->bump_zoom_level = fm_icon_view_bump_zoom_level;
+	fm_directory_view_class->can_rename_file = fm_icon_view_can_rename_file;
 	fm_directory_view_class->can_zoom_in = fm_icon_view_can_zoom_in;
 	fm_directory_view_class->can_zoom_out = fm_icon_view_can_zoom_out;
 	fm_directory_view_class->clear = fm_icon_view_clear;
@@ -2662,7 +2647,7 @@ fm_icon_view_class_init (FMIconViewClass *klass)
         fm_directory_view_class->merge_menus = fm_icon_view_merge_menus;
         fm_directory_view_class->emblems_changed = fm_icon_view_emblems_changed;
         fm_directory_view_class->sort_directories_first_changed = fm_icon_view_sort_directories_first_changed;
-        fm_directory_view_class->start_renaming_item = fm_icon_view_start_renaming_item;
+        fm_directory_view_class->start_renaming_file = fm_icon_view_start_renaming_file;
         fm_directory_view_class->text_attribute_names_changed = fm_icon_view_text_attribute_names_changed;
         fm_directory_view_class->update_menus = fm_icon_view_update_menus;
 
@@ -2693,6 +2678,11 @@ fm_icon_view_instance_init (FMIconView *icon_view)
 	if (!setup_sound_preview) {
 		eel_preferences_add_auto_enum (NAUTILUS_PREFERENCES_PREVIEW_SOUND,
 					       &preview_sound_auto_value);
+
+		eel_preferences_monitor_directory ("/desktop/gnome/sound");
+		eel_preferences_add_auto_boolean ("/desktop/gnome/sound/enable_esd",
+						  &gnome_esd_enabled_auto_value);
+		
 		setup_sound_preview = TRUE;
 	}
 
