@@ -38,9 +38,10 @@
 #include <eel/eel-glib-extensions.h>
 #include <eel/eel-gtk-extensions.h>
 #include <eel/eel-gtk-macros.h>
-#include <eel/eel-image-with-background.h>
+#include <eel/eel-pango-extensions.h>
 #include <eel/eel-string.h>
 #include <gtk/gtkhbox.h>
+#include <gtk/gtkimage.h>
 #include <gtk/gtklabel.h>
 #include <gtk/gtksignal.h>
 #include <gtk/gtkwidget.h>
@@ -79,11 +80,13 @@ static void		   update_all 				   (NautilusSidebarTitle      *sidebar_title);
 static void		   update_title_font			   (NautilusSidebarTitle      *sidebar_title);
 static EelBackground 	  *nautilus_sidebar_title_background       (NautilusSidebarTitle      *sidebar_title);
 
-static const char *non_smooth_font_name;
+static const char *default_font_name;
 
 struct NautilusSidebarTitleDetails {
 	NautilusFile		*file;
-	guint			file_changed_connection;
+	guint			 file_changed_connection;
+	gboolean                 monitoring_count;
+
 	char			*title_text;
 	GtkWidget		*icon;
 	GtkWidget		*title_label;
@@ -91,8 +94,8 @@ struct NautilusSidebarTitleDetails {
 	GtkWidget		*emblem_box;
 	GtkWidget		*notes;
 
-	int			shadow_offset;
-	gboolean		determined_icon;
+	int			 shadow_offset;
+	gboolean		 determined_icon;
 };
 
 EEL_CLASS_BOILERPLATE (NautilusSidebarTitle, nautilus_sidebar_title, gtk_vbox_get_type ())
@@ -110,7 +113,7 @@ nautilus_sidebar_title_class_init (NautilusSidebarTitleClass *class)
 	widget_class->size_allocate = nautilus_sidebar_title_size_allocate;
 
 	eel_preferences_add_auto_string (NAUTILUS_PREFERENCES_DEFAULT_FONT,
-					 &non_smooth_font_name);
+					 &default_font_name);
 }
 
 static void
@@ -128,31 +131,15 @@ realize_callback (NautilusSidebarTitle *sidebar_title)
 
 	g_return_if_fail (background != NULL);
 
-	gtk_signal_connect_while_alive (GTK_OBJECT (background),
-					"appearance_changed",
-					G_CALLBACK (appearance_changed_callback),
-					sidebar_title,
-					GTK_OBJECT (sidebar_title));
-}
-
-#if GNOME2_CONVERSION_COMPLETE
-
-static GdkFont *
-get_non_smooth_font (int font_size)
-{
-	GdkFont *result;
-
-	result = nautilus_font_factory_get_font_by_family (non_smooth_font_name, font_size);
-	g_assert (result != NULL);
-
-	return result;
+	g_signal_connect_object (background, "appearance_changed",
+				 G_CALLBACK (appearance_changed_callback), sidebar_title, 0);
 }
 
 static void
-non_smooth_font_changed_callback (gpointer callback_data)
+default_font_changed_callback (gpointer callback_data)
 {
 	NautilusSidebarTitle *sidebar_title;
-	GdkFont *new_font;
+	PangoFontDescription *font_desc;
 
 	g_return_if_fail (NAUTILUS_IS_SIDEBAR_TITLE (callback_data));
 
@@ -162,29 +149,28 @@ non_smooth_font_changed_callback (gpointer callback_data)
 	update_title_font (sidebar_title);
 
 	/* Update the fixed-size "more info" font */
-	new_font = get_non_smooth_font (MORE_INFO_FONT_SIZE);
-	eel_gtk_widget_set_font (sidebar_title->details->more_info_label,
-				 new_font);	
-	gdk_font_unref (new_font);
+	font_desc = pango_font_description_from_string (default_font_name);
+	pango_font_description_set_size (font_desc, MORE_INFO_FONT_SIZE * PANGO_SCALE);
+	
+	gtk_widget_modify_font (sidebar_title->details->more_info_label,
+				font_desc);
+	pango_font_description_free (font_desc);
+	
 }
 
-#endif
-
 static void
 nautilus_sidebar_title_init (NautilusSidebarTitle *sidebar_title)
 { 
 	sidebar_title->details = g_new0 (NautilusSidebarTitleDetails, 1);
 
 	/* Register to find out about icon theme changes */
-	gtk_signal_connect_object_while_alive (nautilus_icon_factory_get (),
-					       "icons_changed",
-					       G_CALLBACK (update_icon),
-					       GTK_OBJECT (sidebar_title));
+	g_signal_connect_object (nautilus_icon_factory_get (), "icons_changed",
+				 G_CALLBACK (update_icon), sidebar_title, G_CONNECT_SWAPPED);
 	g_signal_connect (sidebar_title, "realize",
-			    G_CALLBACK (realize_callback), NULL);
+			  G_CALLBACK (realize_callback), NULL);
 
 	/* Create the icon */
-	sidebar_title->details->icon = eel_image_new_with_background (NULL);
+	sidebar_title->details->icon = gtk_image_new ();
 	gtk_box_pack_start (GTK_BOX (sidebar_title), sidebar_title->details->icon, 0, 0, 0);
 	gtk_widget_show (sidebar_title->details->icon);
 
@@ -209,12 +195,11 @@ nautilus_sidebar_title_init (NautilusSidebarTitle *sidebar_title)
 
 	/* Keep track of changes in graphics trade offs */
 	update_all (sidebar_title);
-#if GNOME2_CONVERSION_COMPLETE
 	eel_preferences_add_callback_while_alive (NAUTILUS_PREFERENCES_DEFAULT_FONT,
-						  non_smooth_font_changed_callback,
+						  default_font_changed_callback,
 						  sidebar_title,
 						  G_OBJECT (sidebar_title));
-#endif
+
 	eel_preferences_add_callback_while_alive (NAUTILUS_PREFERENCES_THEME,
 						  nautilus_sidebar_title_theme_changed,
 						  sidebar_title,
@@ -222,9 +207,7 @@ nautilus_sidebar_title_init (NautilusSidebarTitle *sidebar_title)
 
 	/* initialize the label colors & fonts */
 	nautilus_sidebar_title_theme_changed (sidebar_title);
-#if GNOME2_CONVERSION_COMPLETE
-	non_smooth_font_changed_callback (sidebar_title);
-#endif
+	default_font_changed_callback (sidebar_title);
 }
 
 /* destroy by throwing away private storage */
@@ -232,8 +215,8 @@ static void
 release_file (NautilusSidebarTitle *sidebar_title)
 {
 	if (sidebar_title->details->file_changed_connection != 0) {
-		gtk_signal_disconnect (GTK_OBJECT (sidebar_title->details->file),
-				       sidebar_title->details->file_changed_connection);
+		g_signal_handler_disconnect (sidebar_title->details->file,
+					     sidebar_title->details->file_changed_connection);
 		sidebar_title->details->file_changed_connection = 0;
 	}
 
@@ -253,7 +236,7 @@ nautilus_sidebar_title_destroy (GtkObject *object)
 
 	if (sidebar_title->details) {
 		release_file (sidebar_title);
-	
+
 		g_free (sidebar_title->details->title_text);
 		g_free (sidebar_title->details);
 		sidebar_title->details = NULL;
@@ -453,28 +436,21 @@ static void
 update_icon (NautilusSidebarTitle *sidebar_title)
 {
 	GdkPixbuf *pixbuf;
-	char *uri;
 	char *icon_name;
 	gboolean leave_pixbuf_unchanged;
 	
 	leave_pixbuf_unchanged = FALSE;
-	uri = NULL;
-	icon_name = NULL;
-	if (sidebar_title->details->file) {
-		uri = nautilus_file_get_uri (sidebar_title->details->file);
-	}	
 
 	/* see if the current content view is specifying an icon */
 	icon_name = get_property_from_component (sidebar_title, "icon_name");
 
 	pixbuf = NULL;
-	if (icon_name != NULL && strlen (icon_name) > 0) {
-		pixbuf = nautilus_icon_factory_get_pixbuf_from_name (icon_name, NULL, NAUTILUS_ICON_SIZE_LARGE, TRUE);
+	if (icon_name != NULL && icon_name[0] != '\0') {
+		pixbuf = nautilus_icon_factory_get_pixbuf_from_name (icon_name, NULL, NAUTILUS_ICON_SIZE_LARGE);
 	} else if (nautilus_icon_factory_is_icon_ready_for_file (sidebar_title->details->file)) {
 		pixbuf = nautilus_icon_factory_get_pixbuf_for_file (sidebar_title->details->file,
 								    "accept",
-								    NAUTILUS_ICON_SIZE_LARGE,
-								    TRUE);
+								    NAUTILUS_ICON_SIZE_LARGE);
 	} else if (sidebar_title->details->determined_icon) {
 		/* We used to know the icon for this file, but now the file says it isn't
 		 * ready. This means that some file info has been invalidated, which
@@ -485,7 +461,6 @@ update_icon (NautilusSidebarTitle *sidebar_title)
 		 leave_pixbuf_unchanged = TRUE;
 	}
 	
-	g_free (uri);	
 	g_free (icon_name);
 	
 	if (pixbuf != NULL) {
@@ -493,7 +468,7 @@ update_icon (NautilusSidebarTitle *sidebar_title)
 	}
 
 	if (!leave_pixbuf_unchanged) {
-		eel_image_set_pixbuf (EEL_IMAGE (sidebar_title->details->icon), pixbuf);
+		gtk_image_set_from_pixbuf (GTK_IMAGE (sidebar_title->details->icon), pixbuf);
 	}
 }
 
@@ -501,13 +476,8 @@ static void
 update_title_font (NautilusSidebarTitle *sidebar_title)
 {
 	int available_width;
-#if GNOME2_CONVERSION_COMPLETE
-	GdkFont *template_font;
-	GdkFont *bold_template_font;
-	GdkFont *largest_fitting_font;
-	int largest_fitting_smooth_font_size;
-	EelScalableFont *smooth_font;
-#endif
+	PangoFontDescription *title_font;
+	int largest_fitting_font_size;
 
 	/* Make sure theres work to do */
 	if (eel_strlen (sidebar_title->details->title_text) < 1) {
@@ -520,47 +490,21 @@ update_title_font (NautilusSidebarTitle *sidebar_title)
 	if (available_width <= 0) {
 		return;
 	}
-	
-#if GNOME2_CONVERSION_COMPLETE
-	/* Update the smooth font */
-	smooth_font = eel_label_get_smooth_font (EEL_LABEL (sidebar_title->details->title_label));
-	largest_fitting_smooth_font_size = eel_scalable_font_largest_fitting_font_size
-		(smooth_font,
-		 sidebar_title->details->title_text,
-		 available_width,
-		 MIN_TITLE_FONT_SIZE,
-		 MAX_TITLE_FONT_SIZE);
-	
-	eel_label_set_smooth_font_size (EEL_LABEL (sidebar_title->details->title_label), 
-					largest_fitting_smooth_font_size);
-	
-	g_object_unref (smooth_font);
 
-	/* Update the regular font */
-	template_font = get_non_smooth_font (MAX_TITLE_FONT_SIZE);
-	bold_template_font = eel_gdk_font_get_bold (template_font);
+	title_font = pango_font_description_from_string (default_font_name);
+	largest_fitting_font_size = eel_pango_font_description_get_largest_fitting_font_size (
+		title_font,
+		gtk_widget_get_pango_context (sidebar_title->details->title_label),
+		sidebar_title->details->title_text,
+		available_width,
+		MIN_TITLE_FONT_SIZE,
+		MAX_TITLE_FONT_SIZE);
+	pango_font_description_set_size (title_font, largest_fitting_font_size * PANGO_SCALE);
+	pango_font_description_set_weight (title_font, PANGO_WEIGHT_BOLD);
 	
-	largest_fitting_font = eel_gdk_font_get_largest_fitting
-		(bold_template_font,
-		 sidebar_title->details->title_text,
-		 available_width,
-		 MIN_TITLE_FONT_SIZE,
-		 MAX_TITLE_FONT_SIZE);
-	
-	if (largest_fitting_font == NULL) {
-		largest_fitting_font = eel_gdk_font_get_fixed ();
-	}
-	
-	eel_gtk_widget_set_font (sidebar_title->details->title_label,
-				 largest_fitting_font);
-	
-	gdk_font_unref (largest_fitting_font);
-	gdk_font_unref (bold_template_font);
-	gdk_font_unref (template_font);
-#else
-	eel_gtk_label_make_bold (GTK_LABEL (sidebar_title->details->title_label));
-	eel_gtk_label_set_scale (GTK_LABEL (sidebar_title->details->title_label), PANGO_SCALE_LARGE);
-#endif
+	gtk_widget_modify_font (sidebar_title->details->title_label,
+				title_font);
+	pango_font_description_free (title_font);
 }
 
 static void
@@ -607,20 +551,15 @@ file_is_search_location (NautilusFile *file)
 }
 
 static int
-measure_width_callback (const char *string, void *context)
+measure_width_callback (const char *string, gpointer callback_data)
 {
-#if GNOME2_CONVERSION_COMPLETE
-	EelLabel *label;
-	EelScalableFont *smooth_font;
-	int smooth_font_size;
-	
-	label = (EelLabel*) context;
-	smooth_font = eel_label_get_smooth_font (label); 
-	smooth_font_size = eel_label_get_smooth_font_size (label);
-	return eel_scalable_font_text_width (smooth_font, smooth_font_size, string, strlen (string));
-#else
-	return 0;
-#endif
+	PangoLayout *layout;
+	int width;
+
+	layout = PANGO_LAYOUT (callback_data);
+	pango_layout_set_text (layout, string, -1);
+	pango_layout_get_pixel_size (layout, &width, NULL);
+	return width;
 }
 
 static void
@@ -632,6 +571,7 @@ update_more_info (NautilusSidebarTitle *sidebar_title)
 	char *search_string, *search_uri;
 	char *date_modified_str;
 	int sidebar_width;
+	PangoLayout *layout;
 	
 	file = sidebar_title->details->file;
 
@@ -666,12 +606,12 @@ update_more_info (NautilusSidebarTitle *sidebar_title)
 			
 			sidebar_width = GTK_WIDGET (sidebar_title)->allocation.width - 2 * SIDEBAR_INFO_MARGIN;
 			if (sidebar_width > MINIMUM_INFO_WIDTH) {
+				layout = pango_layout_copy (gtk_label_get_layout (GTK_LABEL (sidebar_title->details->more_info_label)));
+				pango_layout_set_width (layout, -1);
 				date_modified_str = nautilus_file_fit_modified_date_as_string
-					(file, sidebar_width,
-					 measure_width_callback, NULL,
-					 sidebar_title->details->more_info_label);
+					(file, sidebar_width, measure_width_callback, NULL, layout);
+				g_object_unref (layout);
 				append_and_eat (info_string, "\n", date_modified_str);
-				g_string_append_c (info_string, '\0');
 			}
 		}
 	}
@@ -687,8 +627,7 @@ add_emblem (NautilusSidebarTitle *sidebar_title, GdkPixbuf *pixbuf)
 {
 	GtkWidget *image_widget;
 
-	image_widget = eel_image_new_with_background (NULL);
-	eel_image_set_pixbuf (EEL_IMAGE (image_widget), pixbuf);	
+	image_widget = gtk_image_new_from_pixbuf (pixbuf);
   	gtk_widget_show (image_widget);
 	gtk_container_add (GTK_CONTAINER (sidebar_title->details->emblem_box), image_widget);	
 }
@@ -719,7 +658,7 @@ update_emblems (NautilusSidebarTitle *sidebar_title)
 			(p->data,
 			 NAUTILUS_ICON_SIZE_STANDARD, NAUTILUS_ICON_SIZE_STANDARD,
 			 NAUTILUS_ICON_SIZE_STANDARD, NAUTILUS_ICON_SIZE_STANDARD,
-			 FALSE, NULL, FALSE);
+			 NULL, FALSE);
 		if (pixbuf != NULL) {
 			add_emblem (sidebar_title, pixbuf);
 			g_object_unref (pixbuf);
@@ -767,6 +706,44 @@ nautilus_sidebar_title_set_text (NautilusSidebarTitle *sidebar_title,
 	update_title (sidebar_title);
 }
 
+static gboolean
+item_count_ready (NautilusSidebarTitle *sidebar_title)
+{
+	return sidebar_title->details->file != NULL
+		&& nautilus_file_get_directory_item_count
+		(sidebar_title->details->file, NULL, NULL) != 0;
+}
+
+static void
+monitor_add (NautilusSidebarTitle *sidebar_title)
+{
+	GList *attributes;
+
+	/* Monitor the things needed to get the right icon. Don't
+	 * monitor a directory's item count at first even though the
+	 * "size" attribute is based on that, because the main view
+	 * will get it for us in most cases, and in other cases it's
+	 * OK to not show the size -- if we did monitor it, we'd be in
+	 * a race with the main view and could cause it to have to
+	 * load twice. Once we have a size, though, we want to monitor
+	 * the size to guarantee it stays up to date.
+	 */
+
+	sidebar_title->details->monitoring_count = item_count_ready (sidebar_title);
+
+	attributes = nautilus_icon_factory_get_required_file_attributes ();		
+	attributes = g_list_prepend (attributes,
+				     NAUTILUS_FILE_ATTRIBUTE_METADATA);
+	if (sidebar_title->details->monitoring_count) {
+		attributes = g_list_prepend (attributes,
+					     NAUTILUS_FILE_ATTRIBUTE_DIRECTORY_ITEM_COUNT);
+	}
+
+	nautilus_file_monitor_add (sidebar_title->details->file, sidebar_title, attributes);
+
+	g_list_free (attributes);
+}
+
 static void
 update_all (NautilusSidebarTitle *sidebar_title)
 {
@@ -778,6 +755,12 @@ update_all (NautilusSidebarTitle *sidebar_title)
 	
 	update_emblems (sidebar_title);
 	update_notes (sidebar_title);
+
+	/* Redo monitor once the count is ready. */
+	if (!sidebar_title->details->monitoring_count && item_count_ready (sidebar_title)) {
+		nautilus_file_monitor_remove (sidebar_title->details->file, sidebar_title);
+		monitor_add (sidebar_title);
+	}
 }
 
 void
@@ -785,8 +768,6 @@ nautilus_sidebar_title_set_file (NautilusSidebarTitle *sidebar_title,
 				 NautilusFile *file,
 				 const char *initial_text)
 {
-	GList *attributes;
-
 	if (file != sidebar_title->details->file) {
 		release_file (sidebar_title);
 		sidebar_title->details->file = file;
@@ -796,24 +777,10 @@ nautilus_sidebar_title_set_file (NautilusSidebarTitle *sidebar_title,
 		/* attach file */
 		if (file != NULL) {
 			sidebar_title->details->file_changed_connection =
-				gtk_signal_connect_object (GTK_OBJECT (sidebar_title->details->file),
-							   "changed",
-							   G_CALLBACK (update_all),
-							   GTK_OBJECT (sidebar_title));
-			
-			/* Monitor the things needed to get the right
-			 * icon. Don't monitor a directory's item
-			 * count even though the "size" attribute is
-			 * based on that, because the main view will
-			 * get it for us in most cases, and in other
-			 * cases it's OK to now show the size.
-			 */
-			attributes = nautilus_icon_factory_get_required_file_attributes ();		
-			attributes = g_list_prepend (attributes,
-						     NAUTILUS_FILE_ATTRIBUTE_METADATA);
-			nautilus_file_monitor_add (sidebar_title->details->file, sidebar_title,
-						   attributes);
-			g_list_free (attributes);
+				g_signal_connect_object
+					(sidebar_title->details->file, "changed",
+					 G_CALLBACK (update_all), sidebar_title, G_CONNECT_SWAPPED);
+			monitor_add (sidebar_title);
 		}
 	}
 
