@@ -93,7 +93,6 @@
 
 #define USER_MANUAL_URI		"help:nautilus-user-manual"
 #define QUICK_REFERENCE_URI	"help:nautilus-quick-reference"
-#define RELEASE_NOTES_URI	"help:nautilus-release-notes"
 #define CUSTOMER_FEEDBACK_URI	"http://www.eazel.com/feedback.html"
 #define START_HERE_URI          "start-here:"
 
@@ -651,14 +650,6 @@ help_menu_nautilus_quick_reference_callback (BonoboUIComponent *component,
 	nautilus_window_go_to (NAUTILUS_WINDOW (user_data), QUICK_REFERENCE_URI);
 }
 
-static void
-help_menu_nautilus_release_notes_callback (BonoboUIComponent *component, 
-			              	     gpointer user_data, 
-			              	     const char *verb)
-{
-	nautilus_window_go_to (NAUTILUS_WINDOW (user_data), RELEASE_NOTES_URI);
-}
-
 static void
 help_menu_nautilus_feedback_callback (BonoboUIComponent *component, 
 			              gpointer user_data, 
@@ -1133,7 +1124,6 @@ nautilus_window_initialize_menus_part_1 (NautilusWindow *window)
 		BONOBO_UI_VERB ("About Nautilus", help_menu_about_nautilus_callback),
 		BONOBO_UI_VERB ("Nautilus Manual", help_menu_nautilus_manual_callback),
 		BONOBO_UI_VERB ("Nautilus Quick Reference", help_menu_nautilus_quick_reference_callback),
-		BONOBO_UI_VERB ("Nautilus Release Notes", help_menu_nautilus_release_notes_callback),
 		BONOBO_UI_VERB ("Nautilus Feedback", help_menu_nautilus_feedback_callback),
 		BONOBO_UI_VERB ("User Level Customization", user_level_customize_callback),
 		BONOBO_UI_VERB ("Stop", stop_button_callback),
