@@ -40,7 +40,6 @@
 #include "nautilus-zoom-control.h"
 #include <X11/Xatom.h>
 #include <bonobo/bonobo-exception.h>
-#include <bonobo/bonobo-property-bag-client.h>
 #include <bonobo/bonobo-ui-util.h>
 #include <eel/eel-debug.h>
 #include <eel/eel-gdk-extensions.h>
@@ -58,6 +57,7 @@
 #include <gtk/gtktogglebutton.h>
 #include <gtk/gtkvbox.h>
 #include <libgnome/gnome-i18n.h>
+#include <libgnome/gnome-macros.h>
 #include <libgnome/gnome-util.h>
 #include <libgnomeui/gnome-messagebox.h>
 #include <libgnomeui/gnome-uidefs.h>
@@ -103,7 +103,7 @@
 #define NAUTILUS_MENU_PATH_EXTRA_VIEWER_PLACEHOLDER	"/menu/View/View Choices/Extra Viewer"
 #define NAUTILUS_MENU_PATH_BEFORE_SHORT_LIST_SEPARATOR  "/menu/View/View Choices/Before Short List"
 #define NAUTILUS_MENU_PATH_SHORT_LIST_PLACEHOLDER  	"/menu/View/View Choices/Short List"
-#define NAUTILUS_MENU_PATH_AFTER_SHORT_LIST_SEPARATOR   "/menu/View/View Choices/Before Short List"
+#define NAUTILUS_MENU_PATH_AFTER_SHORT_LIST_SEPARATOR   "/menu/View/View Choices/After Short List"
 
 enum {
 	ARG_0,
@@ -111,88 +111,43 @@ enum {
 	ARG_APP
 };
 
-static GList *history_list = NULL;
+static GList *history_list;
 
-static GdkPixmap *mini_icon_pixmap;
-static GdkBitmap *mini_icon_mask;
+static void update_sidebar_panels_from_preferences (NautilusWindow *window);
+static void sidebar_panels_changed_callback        (gpointer        user_data);
+static void cancel_view_as_callback                (NautilusWindow *window);
 
-static void nautilus_window_class_init          (NautilusWindowClass *klass);
-static void nautilus_window_init                (NautilusWindow      *window);
-static void nautilus_window_destroy                   (GtkObject           *object);
-static void nautilus_window_set_arg                   (GtkObject           *object,
-						       GtkArg              *arg,
-						       guint                arg_id);
-static void nautilus_window_get_arg                   (GtkObject           *object,
-						       GtkArg              *arg,
-						       guint                arg_id);
-static void nautilus_window_size_request              (GtkWidget           *widget,
-						       GtkRequisition      *requisition);
-static void nautilus_window_realize                   (GtkWidget           *widget);
-static void update_sidebar_panels_from_preferences    (NautilusWindow      *window);
-static void sidebar_panels_changed_callback           (gpointer             user_data);
-static void nautilus_window_show                      (GtkWidget           *widget);
-static void nautilus_window_unrealize                 (GtkWidget           *widget);
-static void cancel_view_as_callback                   (NautilusWindow      *window);
-static void real_add_current_location_to_history_list (NautilusWindow      *window);
-
-EEL_CLASS_BOILERPLATE (NautilusWindow,
-			      nautilus_window,
-			      BONOBO_TYPE_WINDOW)
+GNOME_CLASS_BOILERPLATE (NautilusWindow, nautilus_window,
+			 BonoboWindow, BONOBO_TYPE_WINDOW)
 
 static void
-unref_mini_icon (void)
+set_up_default_icon_list (void)
 {
-	gdk_pixmap_unref (mini_icon_pixmap);
-	if (mini_icon_mask != NULL) {
-		gdk_bitmap_unref (mini_icon_mask);
-	}
-}
-
-static void
-nautilus_window_class_init (NautilusWindowClass *klass)
-{
-	GtkObjectClass *object_class;
-	GtkWidgetClass *widget_class;
-	char *filename;
+	GList *icon_list;
+	guint i;
 	GdkPixbuf *pixbuf;
-	
-	object_class = (GtkObjectClass *) klass;
-	widget_class = (GtkWidgetClass *) klass;
+	char *path;
+	const char *icon_filenames[] = { "nautilus-mini-logo.png", "nautilus-launch-icon.png" };
 
-	object_class->destroy = nautilus_window_destroy;
-	object_class->get_arg = nautilus_window_get_arg;
-	object_class->set_arg = nautilus_window_set_arg;
-	
-	widget_class->show = nautilus_window_show;
-	widget_class->unrealize = nautilus_window_unrealize;
-	
-	gtk_object_add_arg_type ("NautilusWindow::app_id",
-				 G_TYPE_STRING,
-				 GTK_ARG_READWRITE | GTK_ARG_CONSTRUCT,
-				 ARG_APP_ID);
-	gtk_object_add_arg_type ("NautilusWindow::app",
-				 G_TYPE_OBJECT,
-				 GTK_ARG_READWRITE | GTK_ARG_CONSTRUCT,
-				 ARG_APP);
-	
-	widget_class->realize = nautilus_window_realize;
-	widget_class->size_request = nautilus_window_size_request;
+	icon_list = NULL;
+	for (i = 0; i < G_N_ELEMENTS (icon_filenames); i++) {
+		path = nautilus_pixmap_file (icon_filenames[i]);
 
-	klass->add_current_location_to_history_list
-		= real_add_current_location_to_history_list;
-
-        filename = nautilus_pixmap_file ("nautilus-mini-logo.png");
-        if (filename != NULL) {
-                pixbuf = gdk_pixbuf_new_from_file (filename, NULL);
-                if (pixbuf != NULL) {
-                        gdk_pixbuf_render_pixmap_and_mask
-				(pixbuf, &mini_icon_pixmap, &mini_icon_mask,
-				 EEL_STANDARD_ALPHA_THRESHHOLD);
-			g_object_unref (pixbuf);
-			eel_debug_call_at_shutdown (unref_mini_icon);
+		if (path == NULL) {
+			continue;
+		}
+		
+		pixbuf = gdk_pixbuf_new_from_file (path, NULL);
+		g_free (path);
+		
+		if (pixbuf != NULL) {
+			icon_list = g_list_prepend (icon_list, pixbuf);
 		}
-        	g_free (filename);
 	}
+
+	gtk_window_set_default_icon_list (icon_list);
+
+	eel_g_list_free_deep_custom (icon_list, (GFunc) g_object_unref, NULL);
 }
 
 static void
@@ -201,10 +156,10 @@ add_sidebar_panel_callback (const char *name,
 			    const char *preference_key,
 			    gpointer callback_data) 
 {
-	g_return_if_fail (name != NULL);
-	g_return_if_fail (iid != NULL);
-	g_return_if_fail (preference_key != NULL);
-	g_return_if_fail (NAUTILUS_IS_WINDOW (callback_data));
+	g_assert (name != NULL);
+	g_assert (iid != NULL);
+	g_assert (preference_key != NULL);
+	g_assert (NAUTILUS_IS_WINDOW (callback_data));
 	
 	eel_preferences_add_callback_while_alive (preference_key,
 						  sidebar_panels_changed_callback,
@@ -213,7 +168,7 @@ add_sidebar_panel_callback (const char *name,
 }
 
 static void
-nautilus_window_init (NautilusWindow *window)
+nautilus_window_instance_init (NautilusWindow *window)
 {
 	window->details = g_new0 (NautilusWindowDetails, 1);
 
@@ -265,7 +220,7 @@ static inline void
 ui_install_idle_handler (NautilusWindow *window)
 {
 	if (window->details->ui_idle_id == 0) {
-		window->details->ui_idle_id = gtk_idle_add_priority (GTK_PRIORITY_LOW, ui_idle_handler, window);
+		window->details->ui_idle_id = g_idle_add_full (G_PRIORITY_LOW, ui_idle_handler, window, NULL);
 	}
 }
 
@@ -273,7 +228,7 @@ static inline void
 ui_remove_idle_handler (NautilusWindow *window)
 {
 	if (window->details->ui_idle_id != 0) {
-		gtk_idle_remove (window->details->ui_idle_id);
+		g_source_remove (window->details->ui_idle_id);
 		window->details->ui_idle_id = 0;
 	}
 }
@@ -348,16 +303,9 @@ nautilus_window_clear_status (gpointer callback_data)
 
 	window = NAUTILUS_WINDOW (callback_data);
 
-	nautilus_window_ui_freeze (window);
-
-	/* FIXME bugzilla.gnome.org 43597:
-	 * Should pass "" or NULL here. This didn't work, then did, now doesn't again.
-	 * When this is fixed in Bonobo we should change this line.
-	 */
-	bonobo_ui_component_set_status (window->details->shell_ui, " ", NULL);
+	bonobo_ui_component_set_status (window->details->status_ui, NULL, NULL);
 	window->status_bar_clear_id = 0;
 
-	nautilus_window_ui_thaw (window);
 	return FALSE;
 }
 
@@ -367,19 +315,15 @@ nautilus_window_set_status (NautilusWindow *window, const char *text)
 	if (window->status_bar_clear_id != 0) {
 		g_source_remove (window->status_bar_clear_id);
 	}
-	
-	nautilus_window_ui_freeze (window);
 
 	if (text != NULL && text[0] != '\0') {
-		bonobo_ui_component_set_status (window->details->shell_ui, text, NULL);
+		bonobo_ui_component_set_status (window->details->status_ui, text, NULL);
 		window->status_bar_clear_id = g_timeout_add
 			(STATUS_BAR_CLEAR_TIMEOUT, nautilus_window_clear_status, window);
 	} else {
 		nautilus_window_clear_status (window);
 		window->status_bar_clear_id = 0;
 	}
-
-	nautilus_window_ui_thaw (window);
 }
 
 void
@@ -531,47 +475,6 @@ set_initial_window_geometry (NautilusWindow *window)
 				          max_height_for_screen));
 }
 
-static gboolean
-location_change_at_idle_callback (gpointer callback_data)
-{
-	NautilusWindow *window;
-	char *location;
-
-	window = NAUTILUS_WINDOW (callback_data);
-
-	location = window->details->location_to_change_to_at_idle;
-	window->details->location_to_change_to_at_idle = NULL;
-	window->details->location_change_at_idle_id = 0;
-
-	nautilus_window_go_to (window, location);
-	g_free (location);
-
-	return FALSE;
-}
-
-
-/* handle bonobo events from the throbber -- since they can come in at
-   any time right in the middle of things, defer until idle */
-static void 
-throbber_callback (BonoboListener *listener,
-		   const char *event_name, 
-		   const CORBA_any *arg,
-		   CORBA_Environment *ev,
-		   gpointer callback_data)
-{
-	NautilusWindow *window;
-
-	window = NAUTILUS_WINDOW (callback_data);
-
-	g_free (window->details->location_to_change_to_at_idle);
-	window->details->location_to_change_to_at_idle = g_strdup (BONOBO_ARG_GET_STRING (arg));
-
-	if (window->details->location_change_at_idle_id == 0) {
-		window->details->location_change_at_idle_id =
-			gtk_idle_add (location_change_at_idle_callback, window);
-	}
-}
-
 /* Add a dummy menu with a "View as ..." item when we first create the
  * view_as_option_menu -- without this the menu draws empty and shrunk,
  * once we populate it it grows and forces the toolbar and all the other
@@ -586,21 +489,52 @@ set_dummy_initial_view_as_menu (NautilusWindow *window)
 	new_menu = gtk_menu_new ();
 	menu_item = gtk_menu_item_new_with_label (_("View as..."));
        	gtk_widget_show (menu_item);
-       	gtk_menu_append (GTK_MENU (new_menu), menu_item);
+       	gtk_menu_shell_append (GTK_MENU_SHELL (new_menu), menu_item);
 
         gtk_option_menu_set_menu (GTK_OPTION_MENU (window->view_as_option_menu),
                                   new_menu);
 }
 
+static void
+nautilus_window_set_up_sidebar (NautilusWindow *window)
+{
+	window->sidebar = nautilus_sidebar_new ();
+
+	if (window->details->location != NULL &&
+	    window->details->title != NULL) {
+		nautilus_sidebar_set_uri (window->sidebar,
+					  window->details->location,
+					  window->details->title);
+	}
+	
+	g_signal_connect_object (window->sidebar, "location_changed",
+				 G_CALLBACK (go_to_callback), window, 0);
+	gtk_paned_pack1 (GTK_PANED (window->content_hbox),
+			 GTK_WIDGET (window->sidebar),
+			 FALSE, TRUE);
+	
+	nautilus_sidebar_setup_width (window->sidebar);
+
+	/* Set up the sidebar panels. */
+	update_sidebar_panels_from_preferences (window);
+
+	gtk_widget_show (GTK_WIDGET (window->sidebar));
+}
+
+static void
+nautilus_window_tear_down_sidebar (NautilusWindow *window)
+{
+	nautilus_window_set_sidebar_panels (window, NULL);
+	gtk_widget_destroy (GTK_WIDGET (window->sidebar));
+	window->sidebar = NULL;
+}
+
 static void
 nautilus_window_constructed (NautilusWindow *window)
 {
 	GtkWidget *location_bar_box;
 	GtkWidget *view_as_menu_vbox;
-  	int sidebar_width;
 	BonoboControl *location_bar_wrapper;
-	CORBA_Environment ev;
-	Bonobo_PropertyBag property_bag;
 	
 	/* CORBA and Bonobo setup, which must be done before the location bar setup */
 	window->details->ui_container = bonobo_ui_container_new ();
@@ -614,6 +548,15 @@ nautilus_window_constructed (NautilusWindow *window)
 		 nautilus_window_get_ui_container (window),
 		 NULL);
 
+	/* Create a separate component so when we remove the status
+	 * we don't loose the status bar
+	 */
+      	window->details->status_ui = bonobo_ui_component_new ("Status Component");
+	bonobo_ui_component_set_container
+		(window->details->status_ui,
+		 nautilus_window_get_ui_container (window),
+		 NULL);
+
 	nautilus_window_ui_freeze (window);
 
 	bonobo_ui_component_freeze (window->details->shell_ui, NULL);
@@ -630,11 +573,10 @@ nautilus_window_constructed (NautilusWindow *window)
 	window->navigation_bar = nautilus_switchable_navigation_bar_new (window);
 	gtk_widget_show (GTK_WIDGET (window->navigation_bar));
 
-	g_signal_connect (window->navigation_bar, "location_changed",
-			    G_CALLBACK (navigation_bar_location_changed_callback), window);
-
-	g_signal_connect (window->navigation_bar, "mode_changed",
-			    G_CALLBACK (navigation_bar_mode_changed_callback), window);
+	g_signal_connect_object (window->navigation_bar, "location_changed",
+				 G_CALLBACK (navigation_bar_location_changed_callback), window, 0);
+	g_signal_connect_object (window->navigation_bar, "mode_changed",
+				 G_CALLBACK (navigation_bar_mode_changed_callback), window, 0);
 
 	gtk_box_pack_start (GTK_BOX (location_bar_box), window->navigation_bar,
 			    TRUE, TRUE, GNOME_PAD_SMALL);
@@ -658,14 +600,18 @@ nautilus_window_constructed (NautilusWindow *window)
 	 * It gets shown later, if the view-frame contains something zoomable.
 	 */
 	window->zoom_control = nautilus_zoom_control_new ();
-	gtk_signal_connect_object (GTK_OBJECT (window->zoom_control), "zoom_in",
-				   G_CALLBACK (nautilus_window_zoom_in), GTK_OBJECT (window));
-	gtk_signal_connect_object (GTK_OBJECT (window->zoom_control), "zoom_out",
-				   G_CALLBACK (nautilus_window_zoom_out), GTK_OBJECT (window));
-	gtk_signal_connect_object (GTK_OBJECT (window->zoom_control), "zoom_to_level",
-				   G_CALLBACK (nautilus_window_zoom_to_level), GTK_OBJECT (window));
-	gtk_signal_connect_object (GTK_OBJECT (window->zoom_control), "zoom_to_fit",
-				   G_CALLBACK (nautilus_window_zoom_to_fit), GTK_OBJECT (window));
+	g_signal_connect_object (window->zoom_control, "zoom_in",
+				 G_CALLBACK (nautilus_window_zoom_in),
+				 window, G_CONNECT_SWAPPED);
+	g_signal_connect_object (window->zoom_control, "zoom_out",
+				 G_CALLBACK (nautilus_window_zoom_out),
+				 window, G_CONNECT_SWAPPED);
+	g_signal_connect_object (window->zoom_control, "zoom_to_level",
+				 G_CALLBACK (nautilus_window_zoom_to_level),
+				 window, G_CONNECT_SWAPPED);
+	g_signal_connect_object (window->zoom_control, "zoom_to_fit",
+				 G_CALLBACK (nautilus_window_zoom_to_fit),
+				 window, G_CONNECT_SWAPPED);
 	gtk_box_pack_end (GTK_BOX (location_bar_box), window->zoom_control, FALSE, FALSE, 0);
 	
 	gtk_widget_show (location_bar_box);
@@ -680,34 +626,15 @@ nautilus_window_constructed (NautilusWindow *window)
 		set_initial_window_geometry (window);
 	
 		window->content_hbox = nautilus_horizontal_splitter_new ();
-		
-		/* FIXME bugzilla.gnome.org 41245: Saved in pixels instead of in %? */
-		/* FIXME bugzilla.gnome.org 41245: No reality check on the value? */
-		sidebar_width = eel_preferences_get_integer (NAUTILUS_PREFERENCES_SIDEBAR_WIDTH);
-		gtk_paned_set_position (GTK_PANED (window->content_hbox), sidebar_width);
+
+		if (eel_preferences_get_boolean (NAUTILUS_PREFERENCES_START_WITH_SIDEBAR)) {
+			nautilus_window_set_up_sidebar (window);
+		}
 	}
+
 	gtk_widget_show (window->content_hbox);
 	bonobo_window_set_contents (BONOBO_WINDOW (window), window->content_hbox);
 	
-	/* FIXME bugzilla.gnome.org 41243: 
-	 * We should use inheritance instead of these special cases
-	 * for the desktop window.
-	 */
-        if (!NAUTILUS_IS_DESKTOP_WINDOW (window)) {
-		/* set up the sidebar */
-		window->sidebar = nautilus_sidebar_new ();
-		gtk_widget_show (GTK_WIDGET (window->sidebar));
-		g_signal_connect (window->sidebar, "location_changed",
-				    G_CALLBACK (go_to_callback), window);
-		gtk_paned_pack1 (GTK_PANED (window->content_hbox),
-				 GTK_WIDGET (window->sidebar),
-				 FALSE, TRUE);
-#if 0
-		bonobo_ui_engine_add_sync (bonobo_window_get_ui_engine (BONOBO_WINDOW (window)),
-					   sidebar_sync);
-#endif
-	}
-	
 	bonobo_ui_component_freeze (window->details->shell_ui, NULL);
 
 	/* FIXME bugzilla.gnome.org 41243: 
@@ -732,7 +659,7 @@ nautilus_window_constructed (NautilusWindow *window)
 					BONOBO_OBJREF (location_bar_wrapper),
 					NULL);
 	bonobo_ui_component_thaw (window->details->shell_ui, NULL);
-	bonobo_object_unref (BONOBO_OBJECT (location_bar_wrapper));
+	bonobo_object_unref (location_bar_wrapper);
 
 	/* initalize the menus and toolbars */
 	nautilus_window_initialize_menus_part_1 (window);
@@ -740,21 +667,6 @@ nautilus_window_constructed (NautilusWindow *window)
 
 	/* We'll do the second part later (bookmarks and go menus) */
 	window->details->ui_pending_initialize_menus_part_2 = TRUE;
-
-	/* watch for throbber location changes, too */
-	if (window->details->throbber != CORBA_OBJECT_NIL) {
-		CORBA_exception_init (&ev);
-		property_bag = Bonobo_Control_getProperties (window->details->throbber, &ev);
-		if (!BONOBO_EX (&ev) && property_bag != CORBA_OBJECT_NIL) {
-			window->details->throbber_listener =
-				bonobo_event_source_client_add_listener_full
-				(property_bag,
-				 g_cclosure_new (G_CALLBACK (throbber_callback), window, NULL), 
-				 "Bonobo/Property:change:location", NULL); 
-			bonobo_object_release_unref (property_bag, NULL);	
-		}
-		CORBA_exception_free (&ev);
-	}
 	
 	/* Set initial sensitivity of some buttons & menu items 
 	 * now that they're all created.
@@ -766,9 +678,6 @@ nautilus_window_constructed (NautilusWindow *window)
 	/* Set up undo manager */
 	nautilus_undo_manager_attach (window->application->undo_manager, G_OBJECT (window));	
 
-	/* Set up the sidebar panels. */
-	update_sidebar_panels_from_preferences (window);
-
 	/* Register that things may be dragged from this window */
 	nautilus_drag_window_register (GTK_WINDOW (window));
 
@@ -776,9 +685,10 @@ nautilus_window_constructed (NautilusWindow *window)
 }
 
 static void
-nautilus_window_set_arg (GtkObject *object,
-			 GtkArg *arg,
-			 guint arg_id)
+nautilus_window_set_property (GObject *object,
+			      guint arg_id,
+			      const GValue *value,
+			      GParamSpec *pspec)
 {
 	char *old_name;
 	NautilusWindow *window;
@@ -787,11 +697,11 @@ nautilus_window_set_arg (GtkObject *object,
 	
 	switch (arg_id) {
 	case ARG_APP_ID:
-		if (GTK_VALUE_STRING (*arg) == NULL) {
+		if (g_value_get_string (value) == NULL) {
 			return;
 		}
 		old_name = bonobo_window_get_name (BONOBO_WINDOW (window));
-		bonobo_window_set_name (BONOBO_WINDOW (window), GTK_VALUE_STRING (*arg));
+		bonobo_window_set_name (BONOBO_WINDOW (window), g_value_get_string (value));
 		/* This hack of using the time when the name first
 		 * goes non-NULL to be window-constructed time is
 		 * completely lame. But it works, so for now we leave
@@ -803,22 +713,25 @@ nautilus_window_set_arg (GtkObject *object,
 		g_free (old_name);
 		break;
 	case ARG_APP:
-		window->application = NAUTILUS_APPLICATION (GTK_VALUE_OBJECT (*arg));
+		window->application = NAUTILUS_APPLICATION (g_value_get_object (value));
 		break;
 	}
 }
 
 static void
-nautilus_window_get_arg (GtkObject *object,
-			 GtkArg *arg,
-			 guint arg_id)
+nautilus_window_get_property (GObject *object,
+			      guint arg_id,
+			      GValue *value,
+			      GParamSpec *pspec)
 {
 	switch (arg_id) {
 	case ARG_APP_ID:
-		GTK_VALUE_STRING (*arg) = bonobo_window_get_name (BONOBO_WINDOW (object));
+		g_value_set_string_take_ownership (
+			value,
+			bonobo_window_get_name (BONOBO_WINDOW (object)));
 		break;
 	case ARG_APP:
-		GTK_VALUE_OBJECT (*arg) = GTK_OBJECT (NAUTILUS_WINDOW (object)->application);
+		g_value_set_object (value, NAUTILUS_WINDOW (object)->application);
 		break;
 	}
 }
@@ -838,107 +751,103 @@ static void
 nautilus_window_unrealize (GtkWidget *widget)
 {
 	NautilusWindow *window;
-	CORBA_Environment ev;
-	Bonobo_PropertyBag property_bag;
 	
 	window = NAUTILUS_WINDOW (widget);
 
-	/* Get rid of the throbber explicitly before it self-destructs
-	 * (which it will do when the control frame goes away.
-	 */
-	if (window->details->throbber != CORBA_OBJECT_NIL) {
-		if (window->details->throbber_listener != CORBA_OBJECT_NIL) {
-			CORBA_exception_init (&ev);
-
-			property_bag = Bonobo_Control_getProperties (window->details->throbber, &ev);
-			if (!BONOBO_EX (&ev) && property_bag != CORBA_OBJECT_NIL) {	
-				bonobo_event_source_client_remove_listener
-					(property_bag, window->details->throbber_listener, NULL);
-				bonobo_object_release_unref (property_bag, NULL);	
-			}
-
-			CORBA_Object_release (window->details->throbber_listener, &ev);
-			window->details->throbber_listener = CORBA_OBJECT_NIL;
-
-			CORBA_exception_free (&ev);
-		}
-
-		bonobo_object_release_unref (window->details->throbber, NULL);
-		window->details->throbber = CORBA_OBJECT_NIL;
+	if (window->details->throbber_property_bag != CORBA_OBJECT_NIL) {
+		bonobo_object_release_unref (window->details->throbber_property_bag, NULL);
+		window->details->throbber_property_bag = CORBA_OBJECT_NIL;
 	}
 
-	EEL_CALL_PARENT (GTK_WIDGET_CLASS, unrealize, (widget));
+	if (window->details->throbber_listener != CORBA_OBJECT_NIL) {
+		CORBA_Object_release (window->details->throbber_listener, NULL);
+		window->details->throbber_listener = CORBA_OBJECT_NIL;
+	}
+
+	GTK_WIDGET_CLASS (parent_class)->unrealize (widget);
 }
 
-static void 
+static void
 nautilus_window_destroy (GtkObject *object)
 {
 	NautilusWindow *window;
 	
 	window = NAUTILUS_WINDOW (object);
 
-	if (window->details != NULL) {
-		/* Handle the part of destroy that's private to the view
-		 * management.
-		 */
-		nautilus_window_manage_views_destroy (window);
+	nautilus_window_manage_views_destroy (window);
 
-		/* Get rid of all callbacks. */
-		nautilus_window_set_viewed_file (window, NULL);
-		nautilus_window_remove_bookmarks_menu_callback (window);
-		nautilus_window_remove_go_menu_callback (window);
-		nautilus_window_toolbar_remove_theme_callback (window);
+	eel_g_object_list_free (window->sidebar_panels);
+	window->sidebar_panels = NULL;
 
-		if (window->details->ui_idle_id != 0) {
-			gtk_idle_remove (window->details->ui_idle_id);
-		}
-
-		/* Get rid of all owned objects. */
-
-		if (window->details->shell_ui != NULL) {
-			bonobo_ui_component_unset_container (window->details->shell_ui, NULL);
-			bonobo_object_unref (BONOBO_OBJECT (window->details->shell_ui));
-		}
-
-		nautilus_file_unref (window->details->viewed_file);
-
-		g_list_free (window->sidebar_panels);
-
-		free_stored_viewers (window);
-	
-		g_free (window->details->location);
-		eel_g_list_free_deep (window->details->selection);
-		eel_g_list_free_deep (window->details->pending_selection);
-
-		nautilus_window_clear_back_list (window);
-		nautilus_window_clear_forward_list (window);
-
-		if (window->current_location_bookmark != NULL) {
-			g_object_unref (window->current_location_bookmark);
-		}
-		if (window->last_location_bookmark != NULL) {
-			g_object_unref (window->last_location_bookmark);
-		}
-	
-		if (window->status_bar_clear_id != 0) {
-			g_source_remove (window->status_bar_clear_id);
-		}
-
-		if (window->details->ui_container != NULL) {
-			bonobo_object_unref (BONOBO_OBJECT (window->details->ui_container));
-		}
-
-		if (window->details->location_change_at_idle_id != 0) {
-			gtk_idle_remove (window->details->location_change_at_idle_id);
-		}
-
-		g_free (window->details->title);
-	
-		g_free (window->details);
-		window->details = NULL;
+	if (window->content_view != NULL) {
+		gtk_object_destroy (GTK_OBJECT (window->content_view));
+		window->content_view = NULL;
 	}
 
-	EEL_CALL_PARENT (GTK_OBJECT_CLASS, destroy, (object));
+	GTK_OBJECT_CLASS (parent_class)->destroy (object);
+}
+
+static void
+nautilus_window_finalize (GObject *object)
+{
+	NautilusWindow *window;
+	
+	window = NAUTILUS_WINDOW (object);
+
+	nautilus_window_manage_views_finalize (window);
+
+	nautilus_window_set_viewed_file (window, NULL);
+	nautilus_window_remove_bookmarks_menu_callback (window);
+	nautilus_window_remove_go_menu_callback (window);
+	nautilus_window_toolbar_remove_theme_callback (window);
+
+	if (window->details->ui_idle_id != 0) {
+		gtk_idle_remove (window->details->ui_idle_id);
+	}
+
+	if (window->details->shell_ui != NULL) {
+		bonobo_ui_component_unset_container (window->details->shell_ui, NULL);
+		bonobo_object_unref (window->details->shell_ui);
+	}
+
+	if (window->details->status_ui != NULL) {
+		bonobo_ui_component_unset_container (window->details->status_ui, NULL);
+		bonobo_object_unref (window->details->status_ui);
+	}
+
+	nautilus_file_unref (window->details->viewed_file);
+
+	free_stored_viewers (window);
+
+	g_free (window->details->location);
+	eel_g_list_free_deep (window->details->selection);
+	eel_g_list_free_deep (window->details->pending_selection);
+
+	nautilus_window_clear_back_list (window);
+	nautilus_window_clear_forward_list (window);
+
+	if (window->current_location_bookmark != NULL) {
+		g_object_unref (window->current_location_bookmark);
+	}
+	if (window->last_location_bookmark != NULL) {
+		g_object_unref (window->last_location_bookmark);
+	}
+
+	if (window->status_bar_clear_id != 0) {
+		g_source_remove (window->status_bar_clear_id);
+	}
+
+	bonobo_object_unref (window->details->ui_container);
+
+	if (window->details->location_change_at_idle_id != 0) {
+		gtk_idle_remove (window->details->location_change_at_idle_id);
+	}
+
+	g_free (window->details->title);
+	
+	g_free (window->details);
+
+	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
 static void
@@ -946,8 +855,8 @@ nautilus_window_save_geometry (NautilusWindow *window)
 {
 	char *geometry_string;
 
-        g_return_if_fail (NAUTILUS_IS_WINDOW (window));
-	g_return_if_fail (GTK_WIDGET_VISIBLE (window));
+        g_assert (NAUTILUS_IS_WINDOW (window));
+	g_assert (GTK_WIDGET_VISIBLE (window));
 
         geometry_string = eel_gtk_window_get_geometry_string (GTK_WINDOW (window));
 
@@ -974,50 +883,6 @@ nautilus_window_close (NautilusWindow *window)
 	gtk_widget_destroy (GTK_WIDGET (window));
 }
 
-static void
-nautilus_window_update_launcher (GdkWindow *window)
-{
-	struct timeval tmp;
-	
-	gettimeofday (&tmp, NULL);
-
-	/* Set a property on the root window to the time of day in seconds.
-	 * The launcher will monitor the root window for this property change
-	 * to update its launching state */
-	gdk_property_change (GDK_ROOT_PARENT (),
-			     gdk_atom_intern ("_NAUTILUS_LAST_WINDOW_REALIZE_TIME", FALSE),
-			     gdk_x11_xatom_to_atom (XA_CARDINAL),
-			     32,
-			     PropModeReplace,
-			     (guchar *) &tmp.tv_sec,
-			     1);
-}
-
-static void
-nautilus_window_realize (GtkWidget *widget)
-{
-	char *filename;
-
-        /* Create our GdkWindow */
-	EEL_CALL_PARENT (GTK_WIDGET_CLASS, realize, (widget));
-
-        /* Set the mini icon */
-	if (mini_icon_pixmap != NULL) {
-		eel_set_mini_icon (widget->window, mini_icon_pixmap, mini_icon_mask);
-	}
-
-	/* Set the maxi icon */
-	filename = gnome_pixmap_file ("nautilus-launch-icon.png");
-	if (filename != NULL) {
-		gnome_window_icon_set_from_file (GTK_WINDOW (widget),
-						 filename);
-		g_free (filename);
-	}
-
-	/* Notify the launcher that our window has been realized */
-	nautilus_window_update_launcher (widget->window);
-}
-
 static void
 nautilus_window_size_request (GtkWidget		*widget,
 			      GtkRequisition	*requisition)
@@ -1025,10 +890,10 @@ nautilus_window_size_request (GtkWidget		*widget,
 	guint max_width;
 	guint max_height;
 
-	g_return_if_fail (NAUTILUS_IS_WINDOW (widget));
-	g_return_if_fail (requisition != NULL);
+	g_assert (NAUTILUS_IS_WINDOW (widget));
+	g_assert (requisition != NULL);
 
-	EEL_CALL_PARENT (GTK_WIDGET_CLASS, size_request, (widget, requisition));
+	GTK_WIDGET_CLASS (parent_class)->size_request (widget, requisition);
 
 	/* Limit the requisition to be within 90% of the available screen 
 	 * real state.
@@ -1119,8 +984,8 @@ view_as_menu_switch_views_callback (GtkWidget *widget, gpointer data)
         NautilusWindow *window;
         int viewer_index;
         
-        g_return_if_fail (GTK_IS_MENU_ITEM (widget));
-        g_return_if_fail (NAUTILUS_IS_WINDOW (data));
+        g_assert (GTK_IS_MENU_ITEM (widget));
+        g_assert (NAUTILUS_IS_WINDOW (data));
 
         window = NAUTILUS_WINDOW (data);
 
@@ -1144,14 +1009,11 @@ create_view_as_menu_item (NautilusWindow *window,
 	menu_item = gtk_menu_item_new_with_label (menu_label);
 	g_free (menu_label);
 
-	g_signal_connect (menu_item,
-			    "activate",
-			    G_CALLBACK (view_as_menu_switch_views_callback),
-			    window);
+	g_signal_connect_object (menu_item, "activate",
+				 G_CALLBACK (view_as_menu_switch_views_callback),
+				 window, 0);
 
-	g_object_set_data (G_OBJECT (menu_item),
-			     "viewer index",
-			     GINT_TO_POINTER (index));
+	g_object_set_data (G_OBJECT (menu_item), "viewer index", GINT_TO_POINTER (index));
 
 	gtk_widget_show (menu_item);
 
@@ -1237,7 +1099,7 @@ update_extra_viewer_in_view_as_menus (NautilusWindow *window,
 	/* Remove menu before changing contents so it is resized properly
 	 * when reattached later in this function.
 	 */
-	gtk_widget_ref (menu);
+	g_object_ref (menu);
 	gtk_option_menu_remove_menu (GTK_OPTION_MENU (window->view_as_option_menu));
 
 	/* Remove old menu item, and either remove or add separator. */
@@ -1248,7 +1110,7 @@ update_extra_viewer_in_view_as_menus (NautilusWindow *window,
 		}
 	} else {
 		if (id != NULL) {
-			gtk_menu_prepend (GTK_MENU (menu), new_gtk_separator ());
+			gtk_menu_shell_prepend (GTK_MENU_SHELL (menu), new_gtk_separator ());
 		}
 	}
 
@@ -1256,11 +1118,11 @@ update_extra_viewer_in_view_as_menus (NautilusWindow *window,
 	if (id != NULL) {
 		new_menu_item = create_view_as_menu_item (window, window->details->extra_viewer, 0);
 		g_object_set_data (G_OBJECT (new_menu_item), "extra viewer", GINT_TO_POINTER (TRUE));
-		gtk_menu_prepend (GTK_MENU (menu), new_menu_item);
+		gtk_menu_shell_prepend (GTK_MENU_SHELL (menu), new_menu_item);
 	}
 
 	gtk_option_menu_set_menu (GTK_OPTION_MENU (window->view_as_option_menu), menu);
-	gtk_widget_unref (menu);
+	g_object_unref (menu);
 
 	/* Also update the Bonobo View menu item */
 	if (id == NULL) {
@@ -1391,8 +1253,8 @@ view_as_menu_choose_view_callback (GtkWidget *widget, gpointer data)
 {
         NautilusWindow *window;
         
-        g_return_if_fail (GTK_IS_MENU_ITEM (widget));
-        g_return_if_fail (NAUTILUS_IS_WINDOW (data));
+        g_assert (GTK_IS_MENU_ITEM (widget));
+        g_assert (NAUTILUS_IS_WINDOW (data));
         
         window = NAUTILUS_WINDOW (data);
 
@@ -1439,7 +1301,7 @@ load_view_as_menus_callback (NautilusFile *file,
 
 	window = NAUTILUS_WINDOW (callback_data);
 
-        g_return_if_fail (GTK_IS_OPTION_MENU (window->view_as_option_menu));
+        g_assert (GTK_IS_OPTION_MENU (window->view_as_option_menu));
 
         /* Clear out the menu items created last time. For the option menu, we need do
          * nothing since we replace the entire menu. For the View menu, we have
@@ -1462,7 +1324,7 @@ load_view_as_menus_callback (NautilusFile *file,
         	 * historical and technical reasons.
         	 */
                 menu_item = create_view_as_menu_item (window, node->data, index);
-                gtk_menu_append (GTK_MENU (new_menu), menu_item);
+                gtk_menu_shell_append (GTK_MENU_SHELL (new_menu), menu_item);
 
 		/* Menu item in View menu. */
                 add_view_as_bonobo_menu_item (window, 
@@ -1473,7 +1335,7 @@ load_view_as_menus_callback (NautilusFile *file,
 
         /* Add/Show separator before "View as..." if there are any other viewers in menu. */
         if (window->details->short_list_viewers != NULL) {
-	        gtk_menu_append (GTK_MENU (new_menu), new_gtk_separator ());
+	        gtk_menu_shell_append (GTK_MENU_SHELL (new_menu), new_gtk_separator ());
         }
         nautilus_bonobo_set_hidden (window->details->shell_ui,
         			    NAUTILUS_MENU_PATH_AFTER_SHORT_LIST_SEPARATOR, 
@@ -1481,12 +1343,10 @@ load_view_as_menus_callback (NautilusFile *file,
 
 	/* Add "View as..." extra bonus choice. */
        	menu_item = gtk_menu_item_new_with_label (_("View as..."));
-        g_signal_connect (menu_item,
-        		    "activate",
-        		    G_CALLBACK (view_as_menu_choose_view_callback),
-        		    window);
+        g_signal_connect_object (menu_item, "activate",
+				 G_CALLBACK (view_as_menu_choose_view_callback), window, 0);
        	gtk_widget_show (menu_item);
-       	gtk_menu_append (GTK_MENU (new_menu), menu_item);
+       	gtk_menu_shell_append (GTK_MENU_SHELL (new_menu), menu_item);
 
         /* We create and attach a new menu here because adding/removing
          * items from existing menu screws up the size of the option menu.
@@ -1534,7 +1394,7 @@ nautilus_window_add_sidebar_panel (NautilusWindow *window,
 	
 	nautilus_sidebar_add_panel (window->sidebar, sidebar_panel);
 
-	gtk_widget_ref (GTK_WIDGET (sidebar_panel));
+	g_object_ref (sidebar_panel);
 	window->sidebar_panels = g_list_prepend (window->sidebar_panels, sidebar_panel);
 }
 
@@ -1550,7 +1410,7 @@ nautilus_window_remove_sidebar_panel (NautilusWindow *window, NautilusViewFrame
 	
 	nautilus_sidebar_remove_panel (window->sidebar, sidebar_panel);
 	window->sidebar_panels = g_list_remove (window->sidebar_panels, sidebar_panel);
-	gtk_widget_unref (GTK_WIDGET (sidebar_panel));
+	g_object_unref (sidebar_panel);
 }
 
 void
@@ -1618,20 +1478,6 @@ nautilus_window_get_search_mode (NautilusWindow *window)
 	== NAUTILUS_SWITCHABLE_NAVIGATION_BAR_MODE_SEARCH;
 }
 
-void
-nautilus_window_go_web_search (NautilusWindow *window)
-{
-	char *search_web_uri;
-
-	nautilus_window_set_search_mode (window, FALSE);
-
-	search_web_uri = eel_preferences_get (NAUTILUS_PREFERENCES_SEARCH_WEB_URI);
-	g_assert (search_web_uri != NULL);
-	
-	nautilus_window_go_to (window, search_web_uri);
-	g_free (search_web_uri);
-}
-
 void
 nautilus_window_go_home (NautilusWindow *window)
 {
@@ -1706,30 +1552,6 @@ nautilus_window_allow_reload (NautilusWindow *window, gboolean allow)
 	nautilus_window_ui_thaw (window);
 }
 
-void
-nautilus_window_allow_stop (NautilusWindow *window, gboolean allow)
-{
-	CORBA_Environment ev;
-	Bonobo_PropertyBag property_bag;
-	
-	nautilus_window_ui_freeze (window);
-
-	nautilus_bonobo_set_sensitive (window->details->shell_ui,
-				       NAUTILUS_COMMAND_STOP, allow);
-
-	if (window->details->throbber != CORBA_OBJECT_NIL) {
-		CORBA_exception_init (&ev);
-		property_bag = Bonobo_Control_getProperties (window->details->throbber, &ev);
-		if (!BONOBO_EX (&ev) && property_bag != CORBA_OBJECT_NIL) {
-			bonobo_pbclient_set_boolean (property_bag, "throbbing", allow, &ev);
-			bonobo_object_release_unref (property_bag, NULL);
-		}
-		CORBA_exception_free (&ev);
-	}
-
-	nautilus_window_ui_thaw (window);
-}
-
 void
 nautilus_send_history_list_changed (void)
 {
@@ -1740,7 +1562,7 @@ nautilus_send_history_list_changed (void)
 static void
 free_history_list (void)
 {
-	eel_gtk_object_list_free (history_list);
+	eel_g_object_list_free (history_list);
 	history_list = NULL;
 }
 
@@ -1780,7 +1602,7 @@ add_to_history_list (NautilusBookmark *bookmark)
 	GList *l, *next;
 	static gboolean free_history_list_is_set_up;
 
-	g_return_if_fail (NAUTILUS_IS_BOOKMARK (bookmark));
+	g_assert (NAUTILUS_IS_BOOKMARK (bookmark));
 
 	if (!free_history_list_is_set_up) {
 		eel_debug_call_at_shutdown (free_history_list);
@@ -1834,20 +1656,20 @@ nautilus_window_add_current_location_to_history_list (NautilusWindow *window)
 	g_assert (NAUTILUS_IS_WINDOW (window));
 
 	EEL_CALL_METHOD (NAUTILUS_WINDOW_CLASS, window,
-			      add_current_location_to_history_list, (window));
+			 add_current_location_to_history_list, (window));
 }
 
 void
 nautilus_window_clear_forward_list (NautilusWindow *window)
 {
-	eel_gtk_object_list_free (window->forward_list);
+	eel_g_object_list_free (window->forward_list);
 	window->forward_list = NULL;
 }
 
 void
 nautilus_window_clear_back_list (NautilusWindow *window)
 {
-	eel_gtk_object_list_free (window->back_list);
+	eel_g_object_list_free (window->back_list);
 	window->back_list = NULL;
 }
 
@@ -1939,9 +1761,9 @@ nautilus_window_set_content_view_widget (NautilusWindow *window,
 			gtk_container_add (GTK_CONTAINER (window->content_hbox),
 					   GTK_WIDGET (new_view));
 		} else {
-			gtk_paned_pack2 (GTK_PANED (window->content_hbox),
-					 GTK_WIDGET (new_view),
-					 TRUE, TRUE);
+			nautilus_horizontal_splitter_pack2 (
+				NAUTILUS_HORIZONTAL_SPLITTER (window->content_hbox),
+				GTK_WIDGET (new_view));
 		}
 	}
 
@@ -2073,22 +1895,22 @@ nautilus_window_toolbar_showing (NautilusWindow *window)
 void 
 nautilus_window_hide_sidebar (NautilusWindow *window)
 {
-	if (window->sidebar == NULL) {
+	if (NAUTILUS_IS_DESKTOP_WINDOW (window) || window->sidebar == NULL) {
 		return;
 	}
-	nautilus_horizontal_splitter_collapse
-		(NAUTILUS_HORIZONTAL_SPLITTER (window->content_hbox));
+
+	nautilus_window_tear_down_sidebar (window);
 	nautilus_window_update_show_hide_menu_items (window);
 }
 
 void 
 nautilus_window_show_sidebar (NautilusWindow *window)
 {
-	if (window->sidebar == NULL) {
+	if (NAUTILUS_IS_DESKTOP_WINDOW (window) || window->sidebar != NULL) {
 		return;
 	}
-	nautilus_horizontal_splitter_expand
-		(NAUTILUS_HORIZONTAL_SPLITTER (window->content_hbox));
+
+	nautilus_window_set_up_sidebar (window);
 	nautilus_window_update_show_hide_menu_items (window);
 }
 
@@ -2097,8 +1919,8 @@ nautilus_window_sidebar_showing (NautilusWindow *window)
 {
 	g_return_val_if_fail (NAUTILUS_IS_WINDOW (window), FALSE);
 
-	return GTK_IS_PANED (window->content_hbox)
-		&& gtk_paned_get_position (GTK_PANED (window->content_hbox)) != 0;
+	return (window->sidebar != NULL) && GTK_IS_PANED (window->content_hbox) 
+		&& nautilus_horizontal_splitter_is_hidden (NAUTILUS_HORIZONTAL_SPLITTER (window->content_hbox));
 }
 
 void 
@@ -2164,7 +1986,7 @@ nautilus_window_show (GtkWidget *widget)
 
 	window = NAUTILUS_WINDOW (widget);
 
-	EEL_CALL_PARENT (GTK_WIDGET_CLASS, show, (widget));
+	GTK_WIDGET_CLASS (parent_class)->show (widget);
 	
 	/* Initially show or hide views based on preferences; once the window is displayed
 	 * these can be controlled on a per-window basis from View menu items. 
@@ -2233,3 +2055,39 @@ nautilus_window_set_viewed_file (NautilusWindow *window,
 	nautilus_file_unref (window->details->viewed_file);
 	window->details->viewed_file = file;
 }
+
+static void
+nautilus_window_class_init (NautilusWindowClass *class)
+{
+	G_OBJECT_CLASS (class)->finalize = nautilus_window_finalize;
+	G_OBJECT_CLASS (class)->get_property = nautilus_window_get_property;
+	G_OBJECT_CLASS (class)->set_property = nautilus_window_set_property;
+	GTK_OBJECT_CLASS (class)->destroy = nautilus_window_destroy;
+	GTK_WIDGET_CLASS (class)->show = nautilus_window_show;
+	GTK_WIDGET_CLASS (class)->unrealize = nautilus_window_unrealize;
+	GTK_WIDGET_CLASS (class)->size_request = nautilus_window_size_request;
+	class->add_current_location_to_history_list = real_add_current_location_to_history_list;
+	
+	g_object_class_install_property (G_OBJECT_CLASS (class),
+					 ARG_APP_ID,
+					 g_param_spec_string ("app_id",
+							      _("Application ID"),
+							      _("The application ID of the window."),
+							      NULL,
+							      G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
+	g_object_class_install_property (G_OBJECT_CLASS (class),
+					 ARG_APP,
+					 g_param_spec_object ("app",
+							      _("Application"),
+							      _("The NautilusApplication associated with this window."),
+							      NAUTILUS_TYPE_APPLICATION,
+							      G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
+	
+	/* Set default for all windows. This probably should be done
+	 * in main or NautilusApplication rather than here in case
+	 * some other window is created before the first
+	 * NautilusWindow. Also, do we really want this icon for
+	 * dialogs?
+	 */
+	set_up_default_icon_list ();
+}
